require 'backports/tools/alias_method'

Backports.alias_method Hash, :key, :index
